@@ -31,10 +31,14 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
- * Support controller class for defining permissions
+ * Short description for 'SupportControllerAcl'
+ * 
+ * Long description (if any) ...
  */
-class SupportControllerAcl extends \Hubzero\Component\AdminController
+class SupportControllerAcl extends Hubzero_Controller
 {
 	/**
 	 * Displays a list of records
@@ -101,7 +105,7 @@ class SupportControllerAcl extends \Hubzero\Component\AdminController
 		// Output messsage and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_SUPPORT_ACL_SAVED')
+			JText::_('ACL successfully updated')
 		);
 	}
 
@@ -142,7 +146,7 @@ class SupportControllerAcl extends \Hubzero\Component\AdminController
 		// Output messsage and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_SUPPORT_ACL_REMOVED')
+			JText::_('ACL successfully removed')
 		);
 	}
 
@@ -176,7 +180,7 @@ class SupportControllerAcl extends \Hubzero\Component\AdminController
 					$user = JUser::getInstance($row->foreign_key);
 					if (!is_object($user))
 					{
-						JError::raiseError(500, JText::_('COM_SUPPORT_ACL_ERROR_UNKNOWN_USER'));
+						JError::raiseError(500, JText::_('Cannot find user'));
 						return;
 					}
 					$row->foreign_key = intval($user->get('id'));
@@ -184,10 +188,12 @@ class SupportControllerAcl extends \Hubzero\Component\AdminController
 				break;
 
 				case 'group':
-					$group = \Hubzero\User\Group::getInstance($row->foreign_key);
+					ximport('Hubzero_Group');
+					
+					$group = Hubzero_Group::getInstance($row->foreign_key);
 					if (!is_object($group))
 					{
-						JError::raiseError(500, JText::_('COM_SUPPORT_ACL_ERROR_UNKNOWN_GROUP'));
+						JError::raiseError(500, JText::_('Cannot find group'));
 						return;
 					}
 					$row->foreign_key = intval($group->gidNumber);
@@ -247,7 +253,7 @@ class SupportControllerAcl extends \Hubzero\Component\AdminController
 		// Output messsage and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_SUPPORT_ACL_SAVED')
+			JText::_('ACL successfully created')
 		);
 	}
 
