@@ -33,44 +33,43 @@ defined('_JEXEC') or die('Restricted access');
 
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'course.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'iterator.php');
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'tags.php');
 
 /**
  * Courses model class for a course
  */
-class CoursesModelCourses extends \Hubzero\Base\Object
+class CoursesModelCourses extends JObject
 {
 	/**
 	 * CoursesTableCourse
-	 *
+	 * 
 	 * @var object
 	 */
 	private $_tbl = NULL;
 
 	/**
 	 * JDatabase
-	 *
+	 * 
 	 * @var object
 	 */
 	private $_db = NULL;
 
 	/**
 	 * CoursesModelIterator
-	 *
+	 * 
 	 * @var object
 	 */
 	private $_courses = null;
 
 	/**
 	 * CoursesModelCourse
-	 *
+	 * 
 	 * @var object
 	 */
 	private $_course = null;
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      integer $id Course ID or alias
 	 * @return     void
 	 */
@@ -94,14 +93,14 @@ class CoursesModelCourses extends \Hubzero\Base\Object
 	{
 		static $instances;
 
-		if (!isset($instances))
+		if (!isset($instances)) 
 		{
 			$instances = array();
 		}
 
-		if (!isset($instances[$oid]))
+		if (!isset($instances[$oid])) 
 		{
-			$instances[$oid] = new self();
+			$instances[$oid] = new CoursesModelCourses();
 		}
 
 		return $instances[$oid];
@@ -115,7 +114,7 @@ class CoursesModelCourses extends \Hubzero\Base\Object
 	 */
 	public function course($id=null)
 	{
-		if (!isset($this->_course)
+		if (!isset($this->_course) 
 		 || ($id !== null && (int) $this->_course->get('id') != $id && (string) $this->_course->get('alias') != $id))
 		{
 			$this->_course = null;
@@ -142,19 +141,18 @@ class CoursesModelCourses extends \Hubzero\Base\Object
 	/**
 	 * Get a list of courses
 	 *   Accepts an array of filters to build query from
-	 *
-	 * @param      array   $filters Filters to build query from
-	 * @param      boolean $clear   Clear cached results?
+	 * 
+	 * @param      array $filters Filters to build query from
 	 * @return     mixed
 	 */
-	public function courses($filters=array(), $clear=false)
+	public function courses($filters=array())
 	{
 		if (isset($filters['count']) && $filters['count'])
 		{
 			return $this->_tbl->getCount($filters);
 		}
 
-		if (!($this->_courses instanceof CoursesModelIterator) || $clear)
+		if (!isset($this->_courses) || !is_a($this->_courses, 'CoursesModelIterator'))
 		{
 			if (($results = $this->_tbl->getRecords($filters)))
 			{
@@ -173,57 +171,5 @@ class CoursesModelCourses extends \Hubzero\Base\Object
 
 		return $this->_courses;
 	}
-
-	/**
-	 * Get a list of courses
-	 *   Accepts an array of filters to build query from
-	 *
-	 * @param      array $filters Filters to build query from
-	 * @return     mixed
-	 */
-	public function userCourses($uid, $type='all', $limit=null, $start=0)
-	{
-		if (($results = $this->_tbl->getUserCourses($uid, $type, $limit, $start)))
-		{
-			foreach ($results as $key => $result)
-			{
-				$results[$key] = new CoursesModelCourse($result);
-			}
-		}
-		else
-		{
-			$results = array();
-		}
-
-		$courses = new CoursesModelIterator($results);
-
-		return $courses;
-	}
-
-	/**
-	 * Get a list of courses
-	 *   Accepts an array of filters to build query from
-	 *
-	 * @param      array $filters Filters to build query from
-	 * @return     mixed
-	 */
-	public function tags($what='cloud', $filters=array(), $clear=false)
-	{
-		$ct = new CoursesModelTags();
-
-		return $ct->render($what, $filters, $clear);
-	}
-
-	/**
-	 * Turn a string of tags to an array
-	 *
-	 * @param      string $tag Tag string
-	 * @return     mixed
-	 */
-	public function parseTags($tag, $remove='')
-	{
-		$ct = new CoursesModelTags();
-		return $ct->parseTags($tag, $remove);
-	}
 }
 
