@@ -75,7 +75,11 @@ class MembersHtml
 	 */
 	public function selectAccess($name, $value, $class='', $id='')
 	{
-		$arr = array(JText::_('Public'), JText::_('Registered users'), JText::_('Private'));
+		$arr = array(
+			0 => JText::_('Public') . JText::_(' (anyone can see)'),
+			1 => JText::_('Registered users') . JText::_(' (only logged in members can see)'), 
+			2 => JText::_('Private') . JText::_(' (only you can see)')
+		);
 
 		$html  = '<select name="' . $name . '"';
 		$html .= ($id)    ? ' id="' . $id . '"'       : '';
