@@ -134,6 +134,16 @@ class TagsTag extends JTable
 
 		$data = new TagsTag($this->_db);
 		$data->load($this->$k);
+		$comment = '';
+		if ($data->tag)
+		{
+			$comment = new stdClass;
+			foreach ($this->getProperties() as $key => $property)
+			{
+				$comment->$key = $property;
+			}
+			$comment = json_encode($comment);
+		}
 
 		$query = 'DELETE FROM #__tags_object WHERE tagid = ' . $this->_db->Quote($this->$k);
 		$this->_db->setQuery($query);
@@ -164,7 +174,7 @@ class TagsTag extends JTable
 		{
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
 			$log = new TagsLog($this->_db);
-			$log->log($oid, 'tag_deleted', json_encode($data));
+			$log->log($oid, 'tag_deleted', $comment);
 		}
 
 		return $result;
@@ -280,6 +290,58 @@ class TagsTag extends JTable
 	 */
 	public function normalize($tag)
 	{
+		//echo htmlentities($tag, ENT_COMPAT, 'UTF-8'); die();
+		//echo htmlspecialchars($tag, ENT_COMPAT, 'UTF-8'); die();
+		//$tag = utf8_decode($tag);
+		$transliterationTable = array(
+			'á' => 'a', 'Á' => 'A', 'à' => 'a', 'À' => 'A', 'ă' => 'a', 'Ă' => 'A', 'â' => 'a', 'Â' => 'A', 'å' => 'a', 'Å' => 'A', 'ã' => 'a', 'Ã' => 'A', 'ą' => 'a', 'Ą' => 'A', 'ā' => 'a', 'Ā' => 'A', 'ä' => 'ae', 'Ä' => 'AE', 'æ' => 'ae', 'Æ' => 'AE', 
+			'ḃ' => 'b', 'Ḃ' => 'B', 
+			'ć' => 'c', 'Ć' => 'C', 'ĉ' => 'c', 'Ĉ' => 'C', 'č' => 'c', 'Č' => 'C', 'ċ' => 'c', 'Ċ' => 'C', 'ç' => 'c', 'Ç' => 'C', 
+			'ď' => 'd', 'Ď' => 'D', 'ḋ' => 'd', 'Ḋ' => 'D', 'đ' => 'd', 'Đ' => 'D', 'ð' => 'dh', 'Ð' => 'Dh', 
+			'é' => 'e', 'É' => 'E', 'è' => 'e', 'È' => 'E', 'ĕ' => 'e', 'Ĕ' => 'E', 'ê' => 'e', 'Ê' => 'E', 'ě' => 'e', 'Ě' => 'E', 'ë' => 'e', 'Ë' => 'E', 'ė' => 'e', 'Ė' => 'E', 'ę' => 'e', 'Ę' => 'E', 'ē' => 'e', 'Ē' => 'E', 
+			'ḟ' => 'f', 'Ḟ' => 'F', 'ƒ' => 'f', 'Ƒ' => 'F', 
+			'ğ' => 'g', 'Ğ' => 'G', 'ĝ' => 'g', 'Ĝ' => 'G', 'ġ' => 'g', 'Ġ' => 'G', 'ģ' => 'g', 'Ģ' => 'G', 
+			'ĥ' => 'h', 'Ĥ' => 'H', 'ħ' => 'h', 'Ħ' => 'H', 
+			'í' => 'i', 'Í' => 'I', 'ì' => 'i', 'Ì' => 'I', 'î' => 'i', 'Î' => 'I', 'ï' => 'i', 'Ï' => 'I', 'ĩ' => 'i', 'Ĩ' => 'I', 'į' => 'i', 'Į' => 'I', 'ī' => 'i', 'Ī' => 'I', 
+			'ĵ' => 'j', 'Ĵ' => 'J', 
+			'ķ' => 'k', 'Ķ' => 'K', 
+			'ĺ' => 'l', 'Ĺ' => 'L', 'ľ' => 'l', 'Ľ' => 'L', 'ļ' => 'l', 'Ļ' => 'L', 'ł' => 'l', 'Ł' => 'L', 
+			'ṁ' => 'm', 'Ṁ' => 'M', 
+			'ń' => 'n', 'Ń' => 'N', 'ň' => 'n', 'Ň' => 'N', 'ñ' => 'n', 'Ñ' => 'N', 'ņ' => 'n', 'Ņ' => 'N', 
+			'ó' => 'o', 'Ó' => 'O', 'ò' => 'o', 'Ò' => 'O', 'ô' => 'o', 'Ô' => 'O', 'ő' => 'o', 'Ő' => 'O', 'õ' => 'o', 'Õ' => 'O', 'ø' => 'oe', 'Ø' => 'OE', 'ō' => 'o', 'Ō' => 'O', 'ơ' => 'o', 'Ơ' => 'O', 'ö' => 'oe', 'Ö' => 'OE', 
+			'ṗ' => 'p', 'Ṗ' => 'P', 
+			'ŕ' => 'r', 'Ŕ' => 'R', 'ř' => 'r', 'Ř' => 'R', 'ŗ' => 'r', 'Ŗ' => 'R', 
+			'ś' => 's', 'Ś' => 'S', 'ŝ' => 's', 'Ŝ' => 'S', 'š' => 's', 'Š' => 'S', 'ṡ' => 's', 'Ṡ' => 'S', 'ş' => 's', 'Ş' => 'S', 'ș' => 's', 'Ș' => 'S', 'ß' => 'SS', 
+			'ť' => 't', 'Ť' => 'T', 'ṫ' => 't', 'Ṫ' => 'T', 'ţ' => 't', 'Ţ' => 'T', 'ț' => 't', 'Ț' => 'T', 'ŧ' => 't', 'Ŧ' => 'T', 
+			'ú' => 'u', 'Ú' => 'U', 'ù' => 'u', 'Ù' => 'U', 'ŭ' => 'u', 'Ŭ' => 'U', 'û' => 'u', 'Û' => 'U', 'ů' => 'u', 'Ů' => 'U', 'ű' => 'u', 'Ű' => 'U', 'ũ' => 'u', 'Ũ' => 'U', 'ų' => 'u', 'Ų' => 'U', 'ū' => 'u', 'Ū' => 'U', 'ư' => 'u', 'Ư' => 'U', 'ü' => 'ue', 'Ü' => 'UE', 
+			'ẃ' => 'w', 'Ẃ' => 'W', 'ẁ' => 'w', 'Ẁ' => 'W', 'ŵ' => 'w', 'Ŵ' => 'W', 'ẅ' => 'w', 'Ẅ' => 'W', 
+			'ý' => 'y', 'Ý' => 'Y', 'ỳ' => 'y', 'Ỳ' => 'Y', 'ŷ' => 'y', 'Ŷ' => 'Y', 'ÿ' => 'y', 'Ÿ' => 'Y', 
+			'ź' => 'z', 'Ź' => 'Z', 'ž' => 'z', 'Ž' => 'Z', 'ż' => 'z', 'Ż' => 'Z', 
+			'þ' => 'th', 'Þ' => 'Th', 'µ' => 'u', 
+			'а' => 'a', 'А' => 'a', 'б' => 'b', 
+			'Б' => 'b', 'в' => 'v', 'В' => 'v', 
+			'г' => 'g', 'Г' => 'g', 'д' => 'd', 
+			'Д' => 'd', 'е' => 'e', 'Е' => 'e', 
+			'ё' => 'e', 'Ё' => 'e', 'ж' => 'zh', 
+			'Ж' => 'zh', 'з' => 'z', 'З' => 'z', 
+			'и' => 'i', 'И' => 'i', 'й' => 'j', 
+			'Й' => 'j', 'к' => 'k', 'К' => 'k', 
+			'л' => 'l', 'Л' => 'l', 'м' => 'm', 
+			'М' => 'm', 'н' => 'n', 'Н' => 'n', 
+			'о' => 'o', 'О' => 'o', 'п' => 'p', 
+			'П' => 'p', 'р' => 'r', 'Р' => 'r', 
+			'с' => 's', 'С' => 's', 'т' => 't', 
+			'Т' => 't', 'у' => 'u', 'У' => 'u', 
+			'ф' => 'f', 'Ф' => 'f', 'х' => 'h', 
+			'Х' => 'h', 'ц' => 'c', 'Ц' => 'c', 
+			'ч' => 'ch', 'Ч' => 'ch', 'ш' => 'sh', 
+			'Ш' => 'sh', 'щ' => 'sch', 'Щ' => 'sch', 
+			'ъ' => '', 'Ъ' => '', 'ы' => 'y', 
+			'Ы' => 'y', 'ь' => '', 'Ь' => '', 
+			'э' => 'e', 'Э' => 'e', 'ю' => 'ju', 
+			'Ю' => 'ju', 'я' => 'ja', 'Я' => 'ja'
+		);
+		$tag = str_replace(array_keys($transliterationTable), array_values($transliterationTable), $tag);
 		return strtolower(preg_replace("/[^a-zA-Z0-9]/", '', $tag));
 	}
 
@@ -508,7 +570,7 @@ class TagsTag extends JTable
 		} 
 		else 
 		{
-			$sql .= ($exclude_private) ? " AND ((tj.tbl='resources' AND R.access!=4) OR (tj.tbl='wiki' AND P.access=0) OR (tj.tbl='xprofiles' AND XP.public=0) OR (tj.tbl!='xprofiles' AND tj.tbl!='wiki' AND tj.tbl!='resources' AND tj.tbl!='wishlist' AND tj.tbl!='support')) " : "";
+			$sql .= ($exclude_private) ? " AND ((tj.tbl='resources' AND R.access!=4 AND R.published=1) OR (tj.tbl='wiki' AND P.access=0 AND P.state<2) OR (tj.tbl='xprofiles' AND XP.public=0) OR tj.tbl NOT IN ('xprofiles','wiki','resources','wishlist','support')) " : "";
 		}
 		$sql .= "GROUP BY tagid ";
 		$sql .= "ORDER BY $order ";
